Svømning - alt om svømning ogtræning i vand - vorespuls.dk
Description: Læs artikler om alt lige fra træningsprogrammer til sikkerhedsråd omkring ophold i vand. Lær nye teknikker og få det mest optimale ud af din svømning.
Keywords: svømning

inspiration til din træning

- Log ind
- eller Opret bruger

Brugernavn: *
Adgangskode: *
Glemt kodeord?
Connect Sign in using Facebook
Søg på dette site:

## Sticky - Svømning

- Få motivationen igen

  ### 4 gode råd: Få svømme-motivation tilbage

  Er motivationen for at komme i svømmehallen helt forsvundet, så får du her 4 gode råd fra vores svømme-ekspert, så du kan komme i gang igen.

  Læs mere
- Test dig selv

  ### Sådan kan du teste din svømmeform

  Mangler du et bevis på, at al det hårde arbejde i vandet har båret frugt? Så test dig selv med en af de her metoder.

  Læs mere

- Spar kræfter og energi

  ### Svømmeguide: Optimer starter og vendinger

  Du kan blive langt hurtigere og optimere din træning, hvis du arbejder på dine starter og vendinger. Læs vores træningsguide til det.

  Læs mere
- Bliv dus med vandet

  ### Gratis svømme-program hver uge på mail

  Vil du forbedre din svømning? Meld dig til vorespuls.dk’ træningsprogram for begyndere og få en mail hver fredag i 12 uger med instruktion.

  Læs mere

## Svømning

- ### Se alle events i februar - MTB, trail, walk-a-thon?

  Artikel
  emner Kom i gang Konkurrence Løb Triatlon Cykling Træning MTB Svømning Kajak Livsstil Aktiv hverdag

  Få en komplet liste over alle events i februar på vorespuls.dk - du finder ikke en bedre undskyldning for at motionere! Læs mere

- ### De har gennemført 271 ironman til sammen

  Artikel
  emner Kom i gang Konkurrence Løb Triatlon Cykling Svømning Mentalt Aktiv hverdag

  271 gange har John Wragg og Elizabeth Model gennemført Ironman tilsammen. Den seneste af slagsen gennemførte de sammen i slutningen af november 2015. Læs mere

- ### Forbedr din præstation med kost-strategi

  Artikel
  emner Løb Triatlon Cykling MTB Svømning Kajak Livsstil Sundhed Kost Aktiv hverdag

  Suppler træningen med en plan for dine madvaner – du vil mærke forskel, når du træner! Få diætistens råd, så du kan spare tid og kræfter. Læs mere

- ### Komplet liste over events i januar - Løb, MTB eller biathlon?

  Artikel
  emner Kom i gang Konkurrence Løb Triatlon Cykling Træning MTB Svømning Kajak Livsstil Aktiv hverdag

  Januar er tiden, hvor mange har det som nytårsfortsæt at dyrke mere motion. Derfor får I her en oversigt over alle vorespuls.dk’s gode grundte til at komme ud og røre sig i det nye år. Læs mere

- ### Så meget mere spiser du i julen

  Artikel
  emner Løb Triatlon Cykling MTB Svømning Kajak Livsstil Kost Vægttab Mentalt

  Vidste du, at alene julemiddagen nemt indeholder en hel dags kalorier? Få ekspertens råd til, hvordan du undgår de ekstra kilo på sidebenene. Læs mere

- ### Så hurtigt spiser sofaen dine muskler!

  Artikel
  emner Kom i gang Løb Triatlon Cykling MTB Skader Svømning Kajak Livsstil Sundhed Kost Vægttab Mentalt Aktiv hverdag

  Lader du sofaen vinde over træningen i blot et par uger, mister du en tredjedel af dine muskler. Og det tager ikke kun 14 dage at opbygge dem igen. Læs mere

- ### Overmotionerer jeg? Det skal du passe på

  Artikel
  emner Løb Triatlon Cykling Træning MTB Svømning Kajak Livsstil Sundhed Mentalt Aktiv hverdag

  Motion er som udgangspunkt sundt. Men for nogen kan det tage overhånd. Sundhedsekspert Bente Klarlund fortæller om advarselssignalerne og faren ved overtræning i artiklen. Læs mere

- ### Professor: Modermælk giver ikke store muskler

  Artikel
  emner Løb Triatlon Cykling Træning MTB Svømning Kajak Livsstil Sundhed Kost

  Det giver ikke større muskler at drikke modermælk, når du styrketræner meget, og det kan være farligt. Så klar er svaret fra en professor i børnernæring. Læs mere

- ### Mænd søger modermælk til styrketræning

  Artikel
  emner Løb Styrke Triatlon Cykling MTB Svømning Kajak Livsstil Sundhed Kost

  Mænd efterlyser modermælk, da de mener, det har en positiv effekt i opbygningen af muskelmasse. Den tendens bekræfter flere internationale medier. Læs mere

- ### Er store muskler egentlig stærkere end små?

  Artikel
  emner Løb Triatlon Cykling Træning MTB Svømning Kajak Livsstil Aktiv hverdag

  Er store muskler stærkere end små muskler? Ja, svarer eksperten, og så alligevel ikke. Få forklaringen her. Læs mere

Flere artikler

# Svømning

## Modtag nyhedsbrevet om svømning

Navn (frivillig):
E-mail: *
Leave this field blank:
Læs seneste nyhedsbreve
vorespuls.dk

Find event
- udfordringer på dit niveau
Løb
Triatlon
Cykling
MTB
Svømning
Kajak
Livsstil
Dato
Format: 01-02-2016

##

Kommende events

1
Feb

- MTB

MTB mekaniker kursus
18:30 Horsens
Myter aflives og erstattes med fakta ;-)...
3
Feb

- Cykling
- MTB

Mekanikerkursus - kun for kvinder
19:00 Rødovre
Er du også en entusiastisk motionist, som...
5
Feb

- MTB

MTB weekend
18:00 Fjerritslev
Mountainbike weekend for ryttere på alle...
6
Feb

- Løb

DGI Sydvest Crossløbs-serien - 3. afd.
14:00 Esbjerg V
Høj puls hele vinteren! Styrk formen og grib...
7
Feb

- Løb

Molboløbet 6
9:00 Nærum
Orienteringsløb for alle med spørgsmål på...

## Tilføj din egen event

Du kan nemt og gratis oprette din event og få den vist på vorespuls.dk. Opret event

## Senest besvarede spørgsmål

- svømmeprogram
- Sovende fingre
- suunto
- Svømning i Kbh´s kanaler.
- svømmedragt

## Seneste artikler

- Se alle events i februar - MTB, trail, walk-a-thon?
- Bloddonor? Så lang tid går der, før kroppen er klar igen
- Sådan foregår en dopingkontrol
- 4 gode råd: Få svømme-motivation tilbage
- 78 år-langt studie: Sådan får du et lykkeligt liv
- De 5 mest tåbelige slankekure nogensinde
- De har gennemført 271 ironman til sammen
- Forbedr din præstation med kost-strategi
- Komplet liste over events i januar - Løb, MTB eller biathlon?
- Så meget mere spiser du i julen

## Populære artikler

Vis seneste artikler

vorespuls.dk
vorespuls.dk drives af:

- DGI
- Nykredit

©2012 Nykredit/DGI
Leave this field blank: